# -*- coding:Utf-8 -*-
import es, playerlib, sqlite3
import sw_config as swConfig
from LecteurDeConfig import LecteurDeConfig as cfg

sw_config = swConfig.Config("config") # Créer une instance avec la classe Config du module sw_config
sql_name = sw_config.get("Config", "Database_Name") # Récupére le nom de la base de donnée
if sql_name == False:
    sql_name = "sorrow"
conn = sqlite3.connect(es.getAddonPath('sorrow') + '/sql/%s'%(sql_name)) # Connexion à la base de données (~ouverture du fichier) 
c = conn.cursor() # Récupération d'un objet qui permet de communiquer avec la base de données

## Création des Tables du script si elles n'exsiste pas
c.execute("CREATE TABLE IF NOT EXISTS player(steamid VARCHAR(20), level TEXT, xp TEXT, ghost INT(1), saveloc TEXT DEFAULT 0)") # Table "player"
c.execute("CREATE TABLE IF NOT EXISTS box(map TEXT, type TEXT, vecteur1 TEXT, vecteur2 TEXT, tp TEXT)") # Table "box"
c.execute("CREATE TABLE IF NOT EXISTS stats(steamid VARCHAR(20), map TEXT, chrono TEXT, finish INT(10))") # Table "stats"

class Player:
    def __init__(self, userid):
        self.userid = userid
        self.steamid = es.getplayersteamid(userid)
    def get(self, option):
        # level = renvoi le level du joueur
        if option == "level":
            player_level = c.execute("SELECT level FROM player WHERE steamid = :steamid", {"steamid" : self.steamid}).fetchone()
            if player_level != None:
                return int(player_level[0])
            else:
                config = swConfig.Config("config")
                defaut_level = config.get("Config", "DefaultLevel")
                return int(defaut_level)
        elif option == "isghost":
            # renvoi si le joueur est en mode "ghost" ou pas
            player_ghost = c.execute("SELECT ghost FROM player WHERE steamid = :steamid", {"steamid" : self.steamid}).fetchone()
            if player_ghost != None and int(player_ghost[0]) == 1:
                return True
            else:
                return False
        elif option == "xp":
            # renvoi l'xp du joueur
            player_level = c.execute("SELECT xp FROM player WHERE steamid = :steamid", {"steamid" : self.steamid}).fetchone()
            if player_level != None:
                return int(player_level[0])
            else:
                return 0
        elif option == "onDatabase":
            # renvoi si le joueur est dans la base de donnée
            player_onDatabase = c.execute("SELECT * FROM player WHERE steamid = :steamid", {"steamid" : self.steamid}).fetchone()
            if player_onDatabase != None:
                return True
            else:
                return False
        elif option == "isadmin":
            # renvoi si le joueur est dans la liste des joueurs
            admin_list = cfg(es.getAddonPath('sorrow')+ '/configuration/adminlist.txt').getLignes()
            if self.steamid in admin_list:
                return True
            else:
                return False
        elif option == "savelocation":
            # renvoi la position sauvegardé par l'admin depuis le menu admin
            save_location = c.execute("SELECT saveloc FROM player WHERE steamid = :steamid", {"steamid" : self.steamid}).fetchone()
            if save_location[0] != "0":
                return save_location[0]
            else:
                return False
        else:
            return False
    def set(self, option, valeur):
        # Donne une valeur au level du joueur
        if option == "level":
            c.execute("UPTADE player SET level = :level WHERE steamid = :steamid", {"level" : valeur, "steamid" : self.steamid})
            return True
        # Donne une valeur à l'xp du joueur
        elif option == "xp":
            c.execute("UPTADE player SET xp = :xp WHERE steamid = :steamid", {"xp" : valeur, "steamid" : self.steamid})
            return True
        # Informe la base de donnée si le joueur est ghost ou pas
        elif option == "isghost":
            c.execute("UPDATE player SET ghost = :ghost WHERE steamid = :steamid", {"ghost" : valeur, "steamid" : self.steamid})
            return True
        # Donne la position sauvegardé par l'admin
        elif option == "savelocation":
            c.execute("UPDATE player SET saveloc = :loc WHERE steamid = :steamid", {"loc": valeur, "steamid" : self.steamid})
            return True
    def create(self):
        # Ajout d'un joueur à la base de donnée
        config = swConfig.Config("config")
        defaut_level = config.get("Config", "DefaultLevel")
        c.execute("INSERT INTO player(steamid, level, xp, ghost) VALUES (:steamid, :level, '0', '0')", {"steamid" : self.steamid, "level" : defaut_level})


# En construction
#class BoxConfig:
#    def __ini__(self, type, map):
#        self.type = type
#        self.map = map
#    def create(self, vector1, vector2, tp):
#        box = c.execute("SELECT type FROM box WHERE type = :type AND map = :map", {"map" : self.map, "type" : self.type}).fetchone()
#        if box[0] != None:
#            c.execute("UPDATE box SET vecteur1 = :vector1, vecteur2 = :vector2 AND tp = :tp WHERE map = :map AND type = :type", {"vector1" : vector1, "vector2" : vector2, "map" : map, "type" : type, "tp" : tp})
#        else:
#            c.execute("INSERT INTO box VALUES(:map, :type, :vector1, :vector2, :tp)", {"map" : self.map, "type" : self.type, "vector1" : vector1, "vector2" : vector2, "tp" : tp})
#        return True
#    def get(self):
#        box = c.execute("SELECT * FROM box WHERE type = :type AND map = :map", {"type" : self.type, "map": self.map}).fecthone()
#       if box != None:
#            return box
#        else:
#            return False